@@ -18,9 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
  */
 
-gboolean remove_key(gpointer key, gpointer data, gpointer arg);
-                                                        /* Clean out GHashTable
-*/
 void ght_remove_key(gpointer data);                     /* Free key */
 void ght_remove_cnu(gpointer data);                     /* Free cnu */
 void ght_remove_cnr(gpointer data);                     /* Free cnr */
