@@ -20,39 +20,30 @@
 
 #include "conference.h"
 
-gboolean remove_key(gpointer key, gpointer data, gpointer arg)
-{
-   log_debug(NAME, "[%s] Auto-removing key %s", FZONE, key);
-
-   free(key);
-   free(data);
-   return TRUE;
-}
-
 void ght_remove_key(gpointer data)
 {
-   log_debug(NAME, "[%s] Auto-removing key %s", FZONE, data);
-   free(data);
+  log_debug(NAME, "[%s] Auto-removing key %s", FZONE, (char*) data);
+  free(data);
 }
-                                                                                                                  
+
 void ght_remove_cnu(gpointer data)
 {
-   cnu node = (cnu)data;
-   log_debug(NAME, "[%s] Auto-removing cnu %s", FZONE, jid_full(jid_fix(node->realid)));
-   pool_free(node->p);
+  cnu node = (cnu)data;
+  log_debug(NAME, "[%s] Auto-removing cnu %s", FZONE, jid_full(node->realid));
+  pool_free(node->p);
 }
-                                                                                                                  
+
 void ght_remove_cnr(gpointer data)
 {
-   cnr node = (cnr)data;
-   log_debug(NAME, "[%s] Auto-removing cnr %s", FZONE, jid_full(jid_fix(node->id)));
-   pool_free(node->p);
+  cnr node = (cnr)data;
+  log_debug(NAME, "[%s] Auto-removing cnr %s", FZONE, jid_full(node->id));
+  pool_free(node->p);
 }
-                                                                                                                  
+
 void ght_remove_xmlnode(gpointer data)
 {
-   xmlnode node = (xmlnode)data;
-   log_debug(NAME, "[%s] Auto-removing xmlnode (%s)", FZONE, xmlnode2str(node));
-   pool_free(node->p);
+  xmlnode node = (xmlnode)data;
+  log_debug(NAME, "[%s] Auto-removing xmlnode (%s)", FZONE, xmlnode2str(node));
+  pool_free(node->p);
 }
 
